@@ -46,13 +46,13 @@ class FNBClient:
                 'status': convert_oag_status_to_normal_form(update_dict['FlightData']['Status'].lower()),
                 'origin_scheduled_dep': parse_date_time(update_dict['FlightData']['SchedDepartureLocal']),
                 'dest_scheduled_arrival': parse_date_time(update_dict['FlightData']['SchedArrivalLocal']),
-                'origin_scheduled_dep_utc': parse_date_time(update_dict['FlightData']['SchedDepartureUtc'], timezone='UTC'),
-                'dest_scheduled_arrival_utc': parse_date_time(update_dict['FlightData']['SchedArrivalUtc'], timezone='UTC'),
+                'origin_scheduled_dep_utc': parse_date_time(update_dict['FlightData']['SchedDepartureUtc']),
+                'dest_scheduled_arrival_utc': parse_date_time(update_dict['FlightData']['SchedArrivalUtc']),
                 'estimated_departure_accuracy': update_dict['FlightData']['LatestDeparture']['Accuracy'],
-                'estimated_departure_utc': parse_date_time(update_dict['FlightData']['LatestDeparture']['DateTimeUtc'], timezone='UTC'),
+                'estimated_departure_utc': parse_date_time(update_dict['FlightData']['LatestDeparture']['DateTimeUtc']),
                 'estimated_departure': parse_date_time(update_dict['FlightData']['LatestDeparture']['DateTimeLocal']),
                 'estimated_arrival_accuracy': update_dict['FlightData']['LatestArrival']['Accuracy'],
-                'estimated_arrival_utc': parse_date_time(update_dict['FlightData']['LatestArrival']['DateTimeUtc'], timezone='UTC'),
+                'estimated_arrival_utc': parse_date_time(update_dict['FlightData']['LatestArrival']['DateTimeUtc']),
                 'estimated_arrival': parse_date_time(update_dict['FlightData']['LatestArrival']['DateTimeLocal']),
                 'origin_terminal': update_dict['FlightData']['DepartureTerminal'],
                 'dest_terminal': update_dict['FlightData']['ArrivalTerminal'],
