@@ -2,17 +2,18 @@ from datetime import datetime, timedelta
 from .airport_time_zone import airport_to_timezone
 import time
 import pytz
+import dateutil.parser
 
-def parse_date_time(datetime_string, timezone=None):
+def parse_date_time(datetime_string):
     if not datetime_string:
         return None
-    return datetime_string
-    # if timezone == 'UTC':
-    #     if datetime_string[-1] != 'Z':
-    #         datetime_string += 'Z'
-    #     return datetime.strptime(datetime_string, '%Y-%m-%dT%H:%M:%SZ').replace(tzinfo=pytz.UTC)
-    # else:
-    #     return datetime.strptime(datetime_string, '%Y-%m-%dT%H:%M:%S')
+
+    date_obj = dateutil.parser.isoparse(datetime_string)
+
+    if date_obj.tzinfo:
+        date_obj = date_obj.replace(tzinfo=None)
+
+    return date_obj
 
 def parse_prev_flight(flight):
     prev_f_number = prev_f_iata = None
